/***************************************************************************
**
** MUI - MagicUserInterface
** (c) 1993 by Stefan Stuntz
**
** Main Header File
**
****************************************************************************
** General Header File Information
****************************************************************************
**
** All macro and structure definitions follow these rules:
**
** Name                       Meaning
**
** MUIC_<class>               Name of a class
** MUIM_<class>_<method>      Method
** MUIP_<class>_<method>      Methods parameter structure
** MUIV_<class>_<method>_<x>  Special method value
** MUIA_<class>_<attrib>      Attribute
** MUIV_<class>_<attrib>_<x>  Special attribute value
** MUIE_<error>               Error return code from MUI_Error()
** MUII_<name>                Standard MUI image
**
** MUIA_... attribute definitions are followed by a comment
** consisting of the three possible letters I, S and G.
** I: it's possible to specify this attribute at object creation time.
** S: it's possible to change this attribute with SetAttrs().
** G: it's possible to get this attribute with GetAttr().
*/


/****************************************************************************/
/** Notify                                                                 **/
/****************************************************************************/

PROC muiC_Notify() RETURN 'Notify.mui'

/* Methods */

CONST MUIM_CallHook                  = $8042b96b /* V4 */
CONST MUIM_FindUData                 = $8042c196 /* V8 */
CONST MUIM_GetUData                  = $8042ed0c /* V8 */
CONST MUIM_KillNotify                = $8042d240 /* V4 */
CONST MUIM_MultiSet                  = $8042d356 /* V7 */
CONST MUIM_Notify                    = $8042c9cb /* V4 */
CONST MUIM_Set                       = $8042549a /* V4 */
CONST MUIM_SetAsString               = $80422590 /* V4 */
CONST MUIM_SetUData                  = $8042c920 /* V8 */
CONST MUIM_WriteLong                 = $80428d86 /* V6 */
CONST MUIM_WriteString               = $80424bf4 /* V6 */

/* Attributes */

CONST MUIA_AppMessage                 = $80421955 /* V5 ..g struct AppMessage * */
CONST MUIA_HelpFile                   = $80423a6e /* V4 isg STRPTR            */
CONST MUIA_HelpLine                   = $8042a825 /* V4 isg LONG              */
CONST MUIA_HelpNode                   = $80420b85 /* V4 isg STRPTR            */
CONST MUIA_NoNotify                   = $804237f9 /* V7 .s. BOOL              */
CONST MUIA_Revision                   = $80427eaa /* V4 ..g LONG              */
CONST MUIA_UserData                   = $80420313 /* V4 isg ULONG             */
CONST MUIA_Version                    = $80422301 /* V4 ..g LONG              */



/****************************************************************************/
/** Family                                                                 **/
/****************************************************************************/

PROC muiC_Family() RETURN 'Family.mui'

/* Methods */

CONST MUIM_Family_AddHead            = $8042e200 /* V8 */
CONST MUIM_Family_AddTail            = $8042d752 /* V8 */
CONST MUIM_Family_Insert             = $80424d34 /* V8 */
CONST MUIM_Family_Remove             = $8042f8a9 /* V8 */
CONST MUIM_Family_Sort               = $80421c49 /* V8 */
CONST MUIM_Family_Transfer           = $8042c14a /* V8 */

/* Attributes */

CONST MUIA_Family_Child               = $8042c696 /* V8 i.. Object *          */



/****************************************************************************/
/** Menustrip                                                              **/
/****************************************************************************/

PROC muiC_Menustrip() RETURN 'Menustrip.mui'

/* Methods */


/* Attributes */

CONST MUIA_Menustrip_Enabled          = $8042815b /* V8 isg BOOL              */



/****************************************************************************/
/** Menu                                                                   **/
/****************************************************************************/

PROC muiC_Menu() RETURN 'Menu.mui'

/* Methods */


/* Attributes */

CONST MUIA_Menu_Enabled               = $8042ed48 /* V8 isg BOOL              */
CONST MUIA_Menu_Title                 = $8042a0e3 /* V8 isg STRPTR            */



/****************************************************************************/
/** Menuitem                                                               **/
/****************************************************************************/

PROC muiC_Menuitem() RETURN 'Menuitem.mui'

/* Methods */


/* Attributes */

CONST MUIA_Menuitem_Checked           = $8042562a /* V8 isg BOOL              */
CONST MUIA_Menuitem_Checkit           = $80425ace /* V8 isg BOOL              */
CONST MUIA_Menuitem_Enabled           = $8042ae0f /* V8 isg BOOL              */
CONST MUIA_Menuitem_Exclude           = $80420bc6 /* V8 isg LONG              */
CONST MUIA_Menuitem_Shortcut          = $80422030 /* V8 isg char              */
CONST MUIA_Menuitem_Title             = $804218be /* V8 isg STRPTR            */
CONST MUIA_Menuitem_Toggle            = $80424d5c /* V8 isg BOOL              */
CONST MUIA_Menuitem_Trigger           = $80426f32 /* V8 ..g struct MenuItem * */



/****************************************************************************/
/** Application                                                            **/
/****************************************************************************/

PROC muiC_Application() RETURN 'Application.mui'

/* Methods */

CONST MUIM_Application_GetMenuCheck  = $8042c0a7 /* V4 */
CONST MUIM_Application_GetMenuState  = $8042a58f /* V4 */
CONST MUIM_Application_Input         = $8042d0f5 /* V4 */
CONST MUIM_Application_InputBuffered = $80427e59 /* V4 */
CONST MUIM_Application_Load          = $8042f90d /* V4 */
CONST MUIM_Application_PushMethod    = $80429ef8 /* V4 */
CONST MUIM_Application_ReturnID      = $804276ef /* V4 */
CONST MUIM_Application_Save          = $804227ef /* V4 */
CONST MUIM_Application_SetMenuCheck  = $8042a707 /* V4 */
CONST MUIM_Application_SetMenuState  = $80428bef /* V4 */
CONST MUIM_Application_ShowHelp      = $80426479 /* V4 */

/* Attributes */

CONST MUIA_Application_Active         = $804260ab /* V4 isg BOOL              */
CONST MUIA_Application_Author         = $80424842 /* V4 i.g STRPTR            */
CONST MUIA_Application_Base           = $8042e07a /* V4 i.g STRPTR            */
CONST MUIA_Application_Broker         = $8042dbce /* V4 ..g Broker *          */
CONST MUIA_Application_BrokerHook     = $80428f4b /* V4 isg struct Hook *     */
CONST MUIA_Application_BrokerPort     = $8042e0ad /* V6 ..g struct MsgPort *  */
CONST MUIA_Application_BrokerPri      = $8042c8d0 /* V6 i.g LONG              */
CONST MUIA_Application_Commands       = $80428648 /* V4 isg struct MUI_Command * */
CONST MUIA_Application_Copyright      = $8042ef4d /* V4 i.g STRPTR            */
CONST MUIA_Application_Description    = $80421fc6 /* V4 i.g STRPTR            */
CONST MUIA_Application_DiskObject     = $804235cb /* V4 isg struct DiskObject * */
CONST MUIA_Application_DoubleStart    = $80423bc6 /* V4 ..g BOOL              */
CONST MUIA_Application_DropObject     = $80421266 /* V5 is. Object *          */
CONST MUIA_Application_ForceQuit      = $804257df /* V8 ..g BOOL              */
CONST MUIA_Application_HelpFile       = $804293f4 /* V8 isg STRPTR            */
CONST MUIA_Application_Iconified      = $8042a07f /* V4 .sg BOOL              */
CONST MUIA_Application_Menu           = $80420e1f /* V4 i.g struct NewMenu *  */
CONST MUIA_Application_MenuAction     = $80428961 /* V4 ..g ULONG             */
CONST MUIA_Application_MenuHelp       = $8042540b /* V4 ..g ULONG             */
CONST MUIA_Application_Menustrip      = $804252d9 /* V8 i.. Object *          */
CONST MUIA_Application_RexxHook       = $80427c42 /* V7 isg struct Hook *     */
CONST MUIA_Application_RexxMsg        = $8042fd88 /* V4 ..g struct RxMsg *    */
CONST MUIA_Application_RexxString     = $8042d711 /* V4 .s. STRPTR            */
CONST MUIA_Application_SingleTask     = $8042a2c8 /* V4 i.. BOOL              */
CONST MUIA_Application_Sleep          = $80425711 /* V4 .s. BOOL              */
CONST MUIA_Application_Title          = $804281b8 /* V4 i.g STRPTR            */
CONST MUIA_Application_Version        = $8042b33f /* V4 i.g STRPTR            */
CONST MUIA_Application_Window         = $8042bfe0 /* V4 i.. Object *          */



/****************************************************************************/
/** Window                                                                 **/
/****************************************************************************/

PROC muiC_Window() RETURN 'Window.mui'

/* Methods */

CONST MUIM_Window_GetMenuCheck       = $80420414 /* V4 */
CONST MUIM_Window_GetMenuState       = $80420d2f /* V4 */
CONST MUIM_Window_ScreenToBack       = $8042913d /* V4 */
CONST MUIM_Window_ScreenToFront      = $804227a4 /* V4 */
CONST MUIM_Window_SetCycleChain      = $80426510 /* V4 */
CONST MUIM_Window_SetMenuCheck       = $80422243 /* V4 */
CONST MUIM_Window_SetMenuState       = $80422b5e /* V4 */
CONST MUIM_Window_ToBack             = $8042152e /* V4 */
CONST MUIM_Window_ToFront            = $8042554f /* V4 */

/* Attributes */

CONST MUIA_Window_Activate            = $80428d2f /* V4 isg BOOL              */
CONST MUIA_Window_ActiveObject        = $80427925 /* V4 .sg Object *          */
CONST MUIA_Window_AltHeight           = $8042cce3 /* V4 i.g LONG              */
CONST MUIA_Window_AltLeftEdge         = $80422d65 /* V4 i.g LONG              */
CONST MUIA_Window_AltTopEdge          = $8042e99b /* V4 i.g LONG              */
CONST MUIA_Window_AltWidth            = $804260f4 /* V4 i.g LONG              */
CONST MUIA_Window_AppWindow           = $804280cf /* V5 i.. BOOL              */
CONST MUIA_Window_Backdrop            = $8042c0bb /* V4 i.. BOOL              */
CONST MUIA_Window_Borderless          = $80429b79 /* V4 i.. BOOL              */
CONST MUIA_Window_CloseGadget         = $8042a110 /* V4 i.. BOOL              */
CONST MUIA_Window_CloseRequest        = $8042e86e /* V4 ..g BOOL              */
CONST MUIA_Window_DefaultObject       = $804294d7 /* V4 isg Object *          */
CONST MUIA_Window_DepthGadget         = $80421923 /* V4 i.. BOOL              */
CONST MUIA_Window_DragBar             = $8042045d /* V4 i.. BOOL              */
CONST MUIA_Window_FancyDrawing        = $8042bd0e /* V8 isg BOOL              */
CONST MUIA_Window_Height              = $80425846 /* V4 i.g LONG              */
CONST MUIA_Window_ID                  = $804201bd /* V4 isg ULONG             */
CONST MUIA_Window_InputEvent          = $804247d8 /* V4 ..g struct InputEvent * */
CONST MUIA_Window_LeftEdge            = $80426c65 /* V4 i.g LONG              */
CONST MUIA_Window_Menu                = $8042db94 /* V4 i.. struct NewMenu *  */
CONST MUIA_Window_MenuAction          = $80427521 /* V8 isg ULONG             */
CONST MUIA_Window_Menustrip           = $8042855e /* V8 i.. Object *          */
CONST MUIA_Window_NoMenus             = $80429df5 /* V4 is. BOOL              */
CONST MUIA_Window_Open                = $80428aa0 /* V4 .sg BOOL              */
CONST MUIA_Window_PublicScreen        = $804278e4 /* V6 isg STRPTR            */
CONST MUIA_Window_RefWindow           = $804201f4 /* V4 is. Object *          */
CONST MUIA_Window_RootObject          = $8042cba5 /* V4 i.. Object *          */
CONST MUIA_Window_Screen              = $8042df4f /* V4 isg struct Screen *   */
CONST MUIA_Window_ScreenTitle         = $804234b0 /* V5 isg STRPTR            */
CONST MUIA_Window_SizeGadget          = $8042e33d /* V4 i.. BOOL              */
CONST MUIA_Window_SizeRight           = $80424780 /* V4 i.. BOOL              */
CONST MUIA_Window_Sleep               = $8042e7db /* V4 .sg BOOL              */
CONST MUIA_Window_Title               = $8042ad3d /* V4 isg STRPTR            */
CONST MUIA_Window_TopEdge             = $80427c66 /* V4 i.g LONG              */
CONST MUIA_Window_Width               = $8042dcae /* V4 i.g LONG              */
CONST MUIA_Window_Window              = $80426a42 /* V4 ..g struct Window *   */

CONST MUIV_Window_ActiveObject_None = 0
CONST MUIV_Window_ActiveObject_Next = -1
CONST MUIV_Window_ActiveObject_Prev = -2
PROC muiV_Window_AltHeightMinMax(p) RETURN (0-(p))
PROC muiV_Window_AltHeightVisible(p) RETURN (-100-(p))
PROC muiV_Window_AltHeightScreen(p) RETURN (-200-(p))
CONST MUIV_Window_AltHeight_Scaled = -1000
CONST MUIV_Window_AltLeftEdge_Centered = -1
CONST MUIV_Window_AltLeftEdge_Moused = -2
CONST MUIV_Window_AltLeftEdge_NoChange = -1000
CONST MUIV_Window_AltTopEdge_Centered = -1
CONST MUIV_Window_AltTopEdge_Moused = -2
PROC muiV_Window_AltTopEdgeDelta(p) RETURN (-3-(p))
CONST MUIV_Window_AltTopEdge_NoChange = -1000
PROC muiV_Window_AltWidthMinMax(p) RETURN (0-(p))
PROC muiV_Window_AltWidthVisible(p) RETURN (-100-(p))
PROC muiV_Window_AltWidthScreen(p) RETURN (-200-(p))
CONST MUIV_Window_AltWidth_Scaled = -1000
PROC muiV_Window_HeightMinMax(p) RETURN (0-(p))
PROC muiV_Window_HeightVisible(p) RETURN (-100-(p))
PROC muiV_Window_HeightScreen(p) RETURN (-200-(p))
CONST MUIV_Window_Height_Scaled = -1000
CONST MUIV_Window_Height_Default = -1001
CONST MUIV_Window_LeftEdge_Centered = -1
CONST MUIV_Window_LeftEdge_Moused = -2
CONST MUIV_Window_Menu_NoMenu = -1
CONST MUIV_Window_TopEdge_Centered = -1
CONST MUIV_Window_TopEdge_Moused = -2
PROC muiV_Window_TopEdgeDelta(p) RETURN (-3-(p))
PROC muiV_Window_WidthMinMax(p) RETURN (0-(p))
PROC muiV_Window_WidthVisible(p) RETURN (-100-(p))
PROC muiV_Window_WidthScreen(p) RETURN (-200-(p))
CONST MUIV_Window_Width_Scaled = -1000
CONST MUIV_Window_Width_Default = -1001


/****************************************************************************/
/** Area                                                                   **/
/****************************************************************************/

PROC muiC_Area() RETURN 'Area.mui'

/* Methods */

CONST MUIM_AskMinMax                 = $80423874 /* V4 */
CONST MUIM_Cleanup                   = $8042d985 /* V4 */
CONST MUIM_Draw                      = $80426f3f /* V4 */
CONST MUIM_HandleInput               = $80422a1a /* V4 */
CONST MUIM_Hide                      = $8042f20f /* V4 */
CONST MUIM_Setup                     = $80428354 /* V4 */
CONST MUIM_Show                      = $8042cc84 /* V4 */

/* Attributes */

CONST MUIA_ApplicationObject          = $8042d3ee /* V4 ..g Object *          */
CONST MUIA_Background                 = $8042545b /* V4 is. LONG              */
CONST MUIA_BottomEdge                 = $8042e552 /* V4 ..g LONG              */
CONST MUIA_ControlChar                = $8042120b /* V4 i.. char              */
CONST MUIA_Disabled                   = $80423661 /* V4 isg BOOL              */
CONST MUIA_ExportID                   = $8042d76e /* V4 isg LONG              */
CONST MUIA_FixHeight                  = $8042a92b /* V4 i.. LONG              */
CONST MUIA_FixHeightTxt               = $804276f2 /* V4 i.. LONG              */
CONST MUIA_FixWidth                   = $8042a3f1 /* V4 i.. LONG              */
CONST MUIA_FixWidthTxt                = $8042d044 /* V4 i.. STRPTR            */
CONST MUIA_Font                       = $8042be50 /* V4 i.g struct TextFont * */
CONST MUIA_Frame                      = $8042ac64 /* V4 i.. LONG              */
CONST MUIA_FramePhantomHoriz          = $8042ed76 /* V4 i.. BOOL              */
CONST MUIA_FrameTitle                 = $8042d1c7 /* V4 i.. STRPTR            */
CONST MUIA_Height                     = $80423237 /* V4 ..g LONG              */
CONST MUIA_HorizWeight                = $80426db9 /* V4 i.. LONG              */
CONST MUIA_InnerBottom                = $8042f2c0 /* V4 i.. LONG              */
CONST MUIA_InnerLeft                  = $804228f8 /* V4 i.. LONG              */
CONST MUIA_InnerRight                 = $804297ff /* V4 i.. LONG              */
CONST MUIA_InnerTop                   = $80421eb6 /* V4 i.. LONG              */
CONST MUIA_InputMode                  = $8042fb04 /* V4 i.. LONG              */
CONST MUIA_LeftEdge                   = $8042bec6 /* V4 ..g LONG              */
CONST MUIA_Pressed                    = $80423535 /* V4 ..g BOOL              */
CONST MUIA_RightEdge                  = $8042ba82 /* V4 ..g LONG              */
CONST MUIA_Selected                   = $8042654b /* V4 isg BOOL              */
CONST MUIA_ShowMe                     = $80429ba8 /* V4 isg BOOL              */
CONST MUIA_ShowSelState               = $8042caac /* V4 i.. BOOL              */
CONST MUIA_Timer                      = $80426435 /* V4 ..g LONG              */
CONST MUIA_TopEdge                    = $8042509b /* V4 ..g LONG              */
CONST MUIA_VertWeight                 = $804298d0 /* V4 i.. LONG              */
CONST MUIA_Weight                     = $80421d1f /* V4 i.. LONG              */
CONST MUIA_Width                      = $8042b59c /* V4 ..g LONG              */
CONST MUIA_Window                     = $80421591 /* V4 ..g struct Window *   */
CONST MUIA_WindowObject               = $8042669e /* V4 ..g Object *          */

CONST MUIV_Font_Inherit = 0
CONST MUIV_Font_Normal = -1
CONST MUIV_Font_List = -2
CONST MUIV_Font_Tiny = -3
CONST MUIV_Font_Fixed = -4
CONST MUIV_Font_Title = -5
CONST MUIV_Font_Big = -6
CONST MUIV_Frame_None = 0
CONST MUIV_Frame_Button = 1
CONST MUIV_Frame_ImageButton = 2
CONST MUIV_Frame_Text = 3
CONST MUIV_Frame_String = 4
CONST MUIV_Frame_ReadList = 5
CONST MUIV_Frame_InputList = 6
CONST MUIV_Frame_Prop = 7
CONST MUIV_Frame_Gauge = 8
CONST MUIV_Frame_Group = 9
CONST MUIV_Frame_PopUp = 10
CONST MUIV_Frame_Virtual = 11
CONST MUIV_Frame_Slider = 12
CONST MUIV_Frame_Count = 13
CONST MUIV_InputMode_None = 0
CONST MUIV_InputMode_RelVerify = 1
CONST MUIV_InputMode_Immediate = 2
CONST MUIV_InputMode_Toggle = 3


/****************************************************************************/
/** Rectangle                                                              **/
/****************************************************************************/

PROC muiC_Rectangle() RETURN 'Rectangle.mui'

/* Attributes */

CONST MUIA_Rectangle_HBar             = $8042c943 /* V7 i.g BOOL              */
CONST MUIA_Rectangle_VBar             = $80422204 /* V7 i.g BOOL              */



/****************************************************************************/
/** Image                                                                  **/
/****************************************************************************/

PROC muiC_Image() RETURN 'Image.mui'

/* Attributes */

CONST MUIA_Image_FontMatch            = $8042815d /* V4 i.. BOOL              */
CONST MUIA_Image_FontMatchHeight      = $80429f26 /* V4 i.. BOOL              */
CONST MUIA_Image_FontMatchWidth       = $804239bf /* V4 i.. BOOL              */
CONST MUIA_Image_FreeHoriz            = $8042da84 /* V4 i.. BOOL              */
CONST MUIA_Image_FreeVert             = $8042ea28 /* V4 i.. BOOL              */
CONST MUIA_Image_OldImage             = $80424f3d /* V4 i.. struct Image *    */
CONST MUIA_Image_Spec                 = $804233d5 /* V4 i.. char *            */
CONST MUIA_Image_State                = $8042a3ad /* V4 is. LONG              */



/****************************************************************************/
/** Bitmap                                                                 **/
/****************************************************************************/

PROC muiC_Bitmap() RETURN 'Bitmap.mui'

/* Attributes */

CONST MUIA_Bitmap_Bitmap              = $804279bd /* V8 isg struct BitMap *   */
CONST MUIA_Bitmap_Height              = $80421560 /* V8 isg LONG              */
CONST MUIA_Bitmap_MappingTable        = $8042e23d /* V8 isg UBYTE *           */
CONST MUIA_Bitmap_SourceColors        = $80425360 /* V8 isg ULONG *           */
CONST MUIA_Bitmap_Transparent         = $80422805 /* V8 isg LONG              */
CONST MUIA_Bitmap_Width               = $8042eb3a /* V8 isg LONG              */



/****************************************************************************/
/** Bodychunk                                                              **/
/****************************************************************************/

PROC muiC_Bodychunk() RETURN 'Bodychunk.mui'

/* Attributes */

CONST MUIA_Bodychunk_Body             = $8042ca67 /* V8 isg UBYTE *           */
CONST MUIA_Bodychunk_Compression      = $8042de5f /* V8 isg UBYTE             */
CONST MUIA_Bodychunk_Depth            = $8042c392 /* V8 isg LONG              */
CONST MUIA_Bodychunk_Masking          = $80423b0e /* V8 isg UBYTE             */



/****************************************************************************/
/** Text                                                                   **/
/****************************************************************************/

PROC muiC_Text() RETURN 'Text.mui'

/* Attributes */

CONST MUIA_Text_Contents              = $8042f8dc /* V4 isg STRPTR            */
CONST MUIA_Text_HiChar                = $804218ff /* V4 i.. char              */
CONST MUIA_Text_PreParse              = $8042566d /* V4 isg STRPTR            */
CONST MUIA_Text_SetMax                = $80424d0a /* V4 i.. BOOL              */
CONST MUIA_Text_SetMin                = $80424e10 /* V4 i.. BOOL              */



/****************************************************************************/
/** String                                                                 **/
/****************************************************************************/

PROC muiC_String() RETURN 'String.mui'

/* Attributes */

CONST MUIA_String_Accept              = $8042e3e1 /* V4 isg STRPTR            */
CONST MUIA_String_Acknowledge         = $8042026c /* V4 ..g STRPTR            */
CONST MUIA_String_AttachedList        = $80420fd2 /* V4 i.. Object *          */
CONST MUIA_String_BufferPos           = $80428b6c /* V4 .sg LONG              */
CONST MUIA_String_Contents            = $80428ffd /* V4 isg STRPTR            */
CONST MUIA_String_DisplayPos          = $8042ccbf /* V4 .sg LONG              */
CONST MUIA_String_EditHook            = $80424c33 /* V7 isg struct Hook *     */
CONST MUIA_String_Format              = $80427484 /* V4 i.g LONG              */
CONST MUIA_String_Integer             = $80426e8a /* V4 isg ULONG             */
CONST MUIA_String_MaxLen              = $80424984 /* V4 i.. LONG              */
CONST MUIA_String_Reject              = $8042179c /* V4 isg STRPTR            */
CONST MUIA_String_Secret              = $80428769 /* V4 i.g BOOL              */

CONST MUIV_String_Format_Left = 0
CONST MUIV_String_Format_Center = 1
CONST MUIV_String_Format_Right = 2


/****************************************************************************/
/** Prop                                                                   **/
/****************************************************************************/

PROC muiC_Prop() RETURN 'Prop.mui'

/* Attributes */

CONST MUIA_Prop_Entries               = $8042fbdb /* V4 isg LONG              */
CONST MUIA_Prop_First                 = $8042d4b2 /* V4 isg LONG              */
CONST MUIA_Prop_Horiz                 = $8042f4f3 /* V4 i.g BOOL              */
CONST MUIA_Prop_Slider                = $80429c3a /* V4 isg BOOL              */
CONST MUIA_Prop_Visible               = $8042fea6 /* V4 isg LONG              */



/****************************************************************************/
/** Gauge                                                                  **/
/****************************************************************************/

PROC muiC_Gauge() RETURN 'Gauge.mui'

/* Attributes */

CONST MUIA_Gauge_Current              = $8042f0dd /* V4 isg LONG              */
CONST MUIA_Gauge_Divide               = $8042d8df /* V4 isg BOOL              */
CONST MUIA_Gauge_Horiz                = $804232dd /* V4 i.. BOOL              */
CONST MUIA_Gauge_InfoText             = $8042bf15 /* V7 isg char *            */
CONST MUIA_Gauge_Max                  = $8042bcdb /* V4 isg LONG              */



/****************************************************************************/
/** Scale                                                                  **/
/****************************************************************************/

PROC muiC_Scale() RETURN 'Scale.mui'

/* Attributes */

CONST MUIA_Scale_Horiz                = $8042919a /* V4 isg BOOL              */



/****************************************************************************/
/** Boopsi                                                                 **/
/****************************************************************************/

PROC muiC_Boopsi() RETURN 'Boopsi.mui'

/* Attributes */

CONST MUIA_Boopsi_Class               = $80426999 /* V4 isg struct IClass *   */
CONST MUIA_Boopsi_ClassID             = $8042bfa3 /* V4 isg char *            */
CONST MUIA_Boopsi_MaxHeight           = $8042757f /* V4 isg ULONG             */
CONST MUIA_Boopsi_MaxWidth            = $8042bcb1 /* V4 isg ULONG             */
CONST MUIA_Boopsi_MinHeight           = $80422c93 /* V4 isg ULONG             */
CONST MUIA_Boopsi_MinWidth            = $80428fb2 /* V4 isg ULONG             */
CONST MUIA_Boopsi_Object              = $80420178 /* V4 ..g Object *          */
CONST MUIA_Boopsi_Remember            = $8042f4bd /* V4 i.. ULONG             */
CONST MUIA_Boopsi_TagDrawInfo         = $8042bae7 /* V4 isg ULONG             */
CONST MUIA_Boopsi_TagScreen           = $8042bc71 /* V4 isg ULONG             */
CONST MUIA_Boopsi_TagWindow           = $8042e11d /* V4 isg ULONG             */



/****************************************************************************/
/** Colorfield                                                             **/
/****************************************************************************/

PROC muiC_Colorfield() RETURN 'Colorfield.mui'

/* Attributes */

CONST MUIA_Colorfield_Blue            = $8042d3b0 /* V4 isg ULONG             */
CONST MUIA_Colorfield_Green           = $80424466 /* V4 isg ULONG             */
CONST MUIA_Colorfield_Pen             = $8042713a /* V4 ..g ULONG             */
CONST MUIA_Colorfield_Red             = $804279f6 /* V4 isg ULONG             */
CONST MUIA_Colorfield_RGB             = $8042677a /* V4 isg ULONG *           */



/****************************************************************************/
/** List                                                                   **/
/****************************************************************************/

PROC muiC_List() RETURN 'List.mui'

/* Methods */

CONST MUIM_List_Clear                = $8042ad89 /* V4 */
CONST MUIM_List_Exchange             = $8042468c /* V4 */
CONST MUIM_List_GetEntry             = $804280ec /* V4 */
CONST MUIM_List_Insert               = $80426c87 /* V4 */
CONST MUIM_List_InsertSingle         = $804254d5 /* V7 */
CONST MUIM_List_Jump                 = $8042baab /* V4 */
CONST MUIM_List_NextSelected         = $80425f17 /* V6 */
CONST MUIM_List_Redraw               = $80427993 /* V4 */
CONST MUIM_List_Remove               = $8042647e /* V4 */
CONST MUIM_List_Select               = $804252d8 /* V4 */
CONST MUIM_List_Sort                 = $80422275 /* V4 */

/* Attributes */

CONST MUIA_List_Active                = $8042391c /* V4 isg LONG              */
CONST MUIA_List_AdjustHeight          = $8042850d /* V4 i.. BOOL              */
CONST MUIA_List_AdjustWidth           = $8042354a /* V4 i.. BOOL              */
CONST MUIA_List_CompareHook           = $80425c14 /* V4 is. struct Hook *     */
CONST MUIA_List_ConstructHook         = $8042894f /* V4 is. struct Hook *     */
CONST MUIA_List_DestructHook          = $804297ce /* V4 is. struct Hook *     */
CONST MUIA_List_DisplayHook           = $8042b4d5 /* V4 is. struct Hook *     */
CONST MUIA_List_Entries               = $80421654 /* V4 ..g LONG              */
CONST MUIA_List_First                 = $804238d4 /* V4 ..g LONG              */
CONST MUIA_List_Format                = $80423c0a /* V4 isg STRPTR            */
CONST MUIA_List_MultiTestHook         = $8042c2c6 /* V4 is. struct Hook *     */
CONST MUIA_List_Quiet                 = $8042d8c7 /* V4 .s. BOOL              */
CONST MUIA_List_SourceArray           = $8042c0a0 /* V4 i.. APTR              */
CONST MUIA_List_Title                 = $80423e66 /* V6 isg char *            */
CONST MUIA_List_Visible               = $8042191f /* V4 ..g LONG              */

CONST MUIV_List_Active_Off = -1
CONST MUIV_List_Active_Top = -2
CONST MUIV_List_Active_Bottom = -3
CONST MUIV_List_Active_Up = -4
CONST MUIV_List_Active_Down = -5
CONST MUIV_List_Active_PageUp = -6
CONST MUIV_List_Active_PageDown = -7
CONST MUIV_List_ConstructHook_String = -1
CONST MUIV_List_DestructHook_String = -1


/****************************************************************************/
/** Floattext                                                              **/
/****************************************************************************/

PROC muiC_Floattext() RETURN 'Floattext.mui'

/* Attributes */

CONST MUIA_Floattext_Justify          = $8042dc03 /* V4 isg BOOL              */
CONST MUIA_Floattext_SkipChars        = $80425c7d /* V4 is. STRPTR            */
CONST MUIA_Floattext_TabSize          = $80427d17 /* V4 is. LONG              */
CONST MUIA_Floattext_Text             = $8042d16a /* V4 isg STRPTR            */



/****************************************************************************/
/** Volumelist                                                             **/
/****************************************************************************/

PROC muiC_Volumelist() RETURN 'Volumelist.mui'


/****************************************************************************/
/** Scrmodelist                                                            **/
/****************************************************************************/

PROC muiC_Scrmodelist() RETURN 'Scrmodelist.mui'

/* Attributes */




/****************************************************************************/
/** Dirlist                                                                **/
/****************************************************************************/

PROC muiC_Dirlist() RETURN 'Dirlist.mui'

/* Methods */

CONST MUIM_Dirlist_ReRead            = $80422d71 /* V4 */

/* Attributes */

CONST MUIA_Dirlist_AcceptPattern      = $8042760a /* V4 is. STRPTR            */
CONST MUIA_Dirlist_Directory          = $8042ea41 /* V4 is. STRPTR            */
CONST MUIA_Dirlist_DrawersOnly        = $8042b379 /* V4 is. BOOL              */
CONST MUIA_Dirlist_FilesOnly          = $8042896a /* V4 is. BOOL              */
CONST MUIA_Dirlist_FilterDrawers      = $80424ad2 /* V4 is. BOOL              */
CONST MUIA_Dirlist_FilterHook         = $8042ae19 /* V4 is. struct Hook *     */
CONST MUIA_Dirlist_MultiSelDirs       = $80428653 /* V6 is. BOOL              */
CONST MUIA_Dirlist_NumBytes           = $80429e26 /* V4 ..g LONG              */
CONST MUIA_Dirlist_NumDrawers         = $80429cb8 /* V4 ..g LONG              */
CONST MUIA_Dirlist_NumFiles           = $8042a6f0 /* V4 ..g LONG              */
CONST MUIA_Dirlist_Path               = $80426176 /* V4 ..g STRPTR            */
CONST MUIA_Dirlist_RejectIcons        = $80424808 /* V4 is. BOOL              */
CONST MUIA_Dirlist_RejectPattern      = $804259c7 /* V4 is. STRPTR            */
CONST MUIA_Dirlist_SortDirs           = $8042bbb9 /* V4 is. LONG              */
CONST MUIA_Dirlist_SortHighLow        = $80421896 /* V4 is. BOOL              */
CONST MUIA_Dirlist_SortType           = $804228bc /* V4 is. LONG              */
CONST MUIA_Dirlist_Status             = $804240de /* V4 ..g LONG              */

CONST MUIV_Dirlist_SortDirs_First = 0
CONST MUIV_Dirlist_SortDirs_Last = 1
CONST MUIV_Dirlist_SortDirs_Mix = 2
CONST MUIV_Dirlist_SortType_Name = 0
CONST MUIV_Dirlist_SortType_Date = 1
CONST MUIV_Dirlist_SortType_Size = 2
CONST MUIV_Dirlist_Status_Invalid = 0
CONST MUIV_Dirlist_Status_Reading = 1
CONST MUIV_Dirlist_Status_Valid = 2


/****************************************************************************/
/** Group                                                                  **/
/****************************************************************************/

PROC muiC_Group() RETURN 'Group.mui'

/* Methods */


/* Attributes */

CONST MUIA_Group_ActivePage           = $80424199 /* V5 isg LONG              */
CONST MUIA_Group_Child                = $804226e6 /* V4 i.. Object *          */
CONST MUIA_Group_Columns              = $8042f416 /* V4 is. LONG              */
CONST MUIA_Group_Horiz                = $8042536b /* V4 i.. BOOL              */
CONST MUIA_Group_HorizSpacing         = $8042c651 /* V4 is. LONG              */
CONST MUIA_Group_PageMode             = $80421a5f /* V5 is. BOOL              */
CONST MUIA_Group_Rows                 = $8042b68f /* V4 is. LONG              */
CONST MUIA_Group_SameHeight           = $8042037e /* V4 i.. BOOL              */
CONST MUIA_Group_SameSize             = $80420860 /* V4 i.. BOOL              */
CONST MUIA_Group_SameWidth            = $8042b3ec /* V4 i.. BOOL              */
CONST MUIA_Group_Spacing              = $8042866d /* V4 is. LONG              */
CONST MUIA_Group_VertSpacing          = $8042e1bf /* V4 is. LONG              */



/****************************************************************************/
/** Register                                                               **/
/****************************************************************************/

PROC muiC_Register() RETURN 'Register.mui'

/* Attributes */

CONST MUIA_Register_Frame             = $8042349b /* V7 i.g BOOL              */
CONST MUIA_Register_Titles            = $804297ec /* V7 i.g STRPTR *          */



/****************************************************************************/
/** Virtgroup                                                              **/
/****************************************************************************/

PROC muiC_Virtgroup() RETURN 'Virtgroup.mui'

/* Methods */


/* Attributes */

CONST MUIA_Virtgroup_Height           = $80423038 /* V6 ..g LONG              */
CONST MUIA_Virtgroup_Left             = $80429371 /* V6 isg LONG              */
CONST MUIA_Virtgroup_Top              = $80425200 /* V6 isg LONG              */
CONST MUIA_Virtgroup_Width            = $80427c49 /* V6 ..g LONG              */



/****************************************************************************/
/** Scrollgroup                                                            **/
/****************************************************************************/

PROC muiC_Scrollgroup() RETURN 'Scrollgroup.mui'

/* Attributes */

CONST MUIA_Scrollgroup_Contents       = $80421261 /* V4 i.. Object *          */



/****************************************************************************/
/** Scrollbar                                                              **/
/****************************************************************************/

PROC muiC_Scrollbar() RETURN 'Scrollbar.mui'


/****************************************************************************/
/** Listview                                                               **/
/****************************************************************************/

PROC muiC_Listview() RETURN 'Listview.mui'

/* Attributes */

CONST MUIA_Listview_ClickColumn       = $8042d1b3 /* V7 ..g LONG              */
CONST MUIA_Listview_DefClickColumn    = $8042b296 /* V7 isg LONG              */
CONST MUIA_Listview_DoubleClick       = $80424635 /* V4 i.g BOOL              */
CONST MUIA_Listview_Input             = $8042682d /* V4 i.. BOOL              */
CONST MUIA_Listview_List              = $8042bcce /* V4 i.. Object *          */
CONST MUIA_Listview_MultiSelect       = $80427e08 /* V7 i.. LONG              */
CONST MUIA_Listview_SelectChange      = $8042178f /* V4 ..g BOOL              */

CONST MUIV_Listview_MultiSelect_None = 0
CONST MUIV_Listview_MultiSelect_Default = 1
CONST MUIV_Listview_MultiSelect_Shifted = 2
CONST MUIV_Listview_MultiSelect_Always = 3


/****************************************************************************/
/** Radio                                                                  **/
/****************************************************************************/

PROC muiC_Radio() RETURN 'Radio.mui'

/* Attributes */

CONST MUIA_Radio_Active               = $80429b41 /* V4 isg LONG              */
CONST MUIA_Radio_Entries              = $8042b6a1 /* V4 i.. STRPTR *          */



/****************************************************************************/
/** Cycle                                                                  **/
/****************************************************************************/

PROC muiC_Cycle() RETURN 'Cycle.mui'

/* Attributes */

CONST MUIA_Cycle_Active               = $80421788 /* V4 isg LONG              */
CONST MUIA_Cycle_Entries              = $80420629 /* V4 i.. STRPTR *          */

CONST MUIV_Cycle_Active_Next = -1
CONST MUIV_Cycle_Active_Prev = -2


/****************************************************************************/
/** Slider                                                                 **/
/****************************************************************************/

PROC muiC_Slider() RETURN 'Slider.mui'

/* Attributes */

CONST MUIA_Slider_Level               = $8042ae3a /* V4 isg LONG              */
CONST MUIA_Slider_Max                 = $8042d78a /* V4 i.. LONG              */
CONST MUIA_Slider_Min                 = $8042e404 /* V4 i.. LONG              */
CONST MUIA_Slider_Quiet               = $80420b26 /* V6 i.. BOOL              */
CONST MUIA_Slider_Reverse             = $8042f2a0 /* V4 isg BOOL              */



/****************************************************************************/
/** Coloradjust                                                            **/
/****************************************************************************/

PROC muiC_Coloradjust() RETURN 'Coloradjust.mui'

/* Attributes */

CONST MUIA_Coloradjust_Blue           = $8042b8a3 /* V4 isg ULONG             */
CONST MUIA_Coloradjust_Green          = $804285ab /* V4 isg ULONG             */
CONST MUIA_Coloradjust_ModeID         = $8042ec59 /* V4 isg ULONG             */
CONST MUIA_Coloradjust_Red            = $80420eaa /* V4 isg ULONG             */
CONST MUIA_Coloradjust_RGB            = $8042f899 /* V4 isg ULONG *           */



/****************************************************************************/
/** Palette                                                                **/
/****************************************************************************/

PROC muiC_Palette() RETURN 'Palette.mui'

/* Attributes */

CONST MUIA_Palette_Entries            = $8042a3d8 /* V6 i.g struct MUI_Palette_Entry * */
CONST MUIA_Palette_Groupable          = $80423e67 /* V6 isg BOOL              */
CONST MUIA_Palette_Names              = $8042c3a2 /* V6 isg char **           */



/****************************************************************************/
/** Colorpanel                                                             **/
/****************************************************************************/

PROC muiC_Colorpanel() RETURN 'Colorpanel.mui'

/* Methods */


/* Attributes */




/****************************************************************************/
/** Popstring                                                              **/
/****************************************************************************/

PROC muiC_Popstring() RETURN 'Popstring.mui'

/* Methods */

CONST MUIM_Popstring_Close           = $8042dc52 /* V7 */
CONST MUIM_Popstring_Open            = $804258ba /* V7 */

/* Attributes */

CONST MUIA_Popstring_Button           = $8042d0b9 /* V7 i.g Object *          */
CONST MUIA_Popstring_CloseHook        = $804256bf /* V7 isg struct Hook *     */
CONST MUIA_Popstring_OpenHook         = $80429d00 /* V7 isg struct Hook *     */
CONST MUIA_Popstring_String           = $804239ea /* V7 i.g Object *          */
CONST MUIA_Popstring_Toggle           = $80422b7a /* V7 isg BOOL              */



/****************************************************************************/
/** Popobject                                                              **/
/****************************************************************************/

PROC muiC_Popobject() RETURN 'Popobject.mui'

/* Attributes */

CONST MUIA_Popobject_Follow           = $80424cb5 /* V7 isg BOOL              */
CONST MUIA_Popobject_Light            = $8042a5a3 /* V7 isg BOOL              */
CONST MUIA_Popobject_Object           = $804293e3 /* V7 i.g Object *          */
CONST MUIA_Popobject_ObjStrHook       = $8042db44 /* V7 isg struct Hook *     */
CONST MUIA_Popobject_StrObjHook       = $8042fbe1 /* V7 isg struct Hook *     */
CONST MUIA_Popobject_Volatile         = $804252ec /* V7 isg BOOL              */



/****************************************************************************/
/** Poplist                                                                **/
/****************************************************************************/

PROC muiC_Poplist() RETURN 'Poplist.mui'

/* Attributes */

CONST MUIA_Poplist_Array              = $8042084c /* V8 i.. char **           */



/****************************************************************************/
/** Popasl                                                                 **/
/****************************************************************************/

PROC muiC_Popasl() RETURN 'Popasl.mui'

/* Attributes */

CONST MUIA_Popasl_Active              = $80421b37 /* V7 ..g BOOL              */
CONST MUIA_Popasl_StartHook           = $8042b703 /* V7 isg struct Hook *     */
CONST MUIA_Popasl_StopHook            = $8042d8d2 /* V7 isg struct Hook *     */
CONST MUIA_Popasl_Type                = $8042df3d /* V7 i.g ULONG             */


/* PROC main() RETURN 10   dummy */
